@@ -557,7 +557,7 @@ class TranslationSolvers():
 
     def solve_ssa(self, ke, t, ki=.33, kt = 10,
                   x0=[], n_traj=100, bins=None, low_memory=True,
-                  perturb=[0,0,0], leaky_probes=False, kprobe=np.ones(1),
+                  perturb=[0,0,0,0], leaky_probes=False, kprobe=np.ones(1),
                   record_stats=False, probe_vec=None, probe_loc=None,
                   kon=1, koff=1, bursting=False, rib_prealloc=200,
                   dynamic_prealloc=False):
